@@ -4,13 +4,14 @@ use warnings;
 use base 'Catalyst::Controller';
 use Captcha::reCAPTCHA;
 use Carp 'croak';
-our $VERSION = '0.30001';
+our $VERSION = '0.4';
 
 
 sub captcha_get : Private {
     my ($self, $c) = @_;
     my $cap = Captcha::reCAPTCHA->new;
-    $c->stash->{recaptcha} = $cap->get_html($c->config->{recaptcha}->{pub_key});
+    $c->stash->{recaptcha} =
+        $cap->get_html($c->config->{recaptcha}->{pub_key});
     return;
 }
 
@@ -18,15 +19,17 @@ sub captcha_check : Private {
     my ($self, $c) = @_;
     my $cap = Captcha::reCAPTCHA->new;
     my $challenge = $c->req->param('recaptcha_challenge_field');
-    my $response = $c->req->param('recaptcha_response_field');
-    
+    my $response  = $c->req->param('recaptcha_response_field');
+
     unless ( $response && $challenge ) {
-        $c->stash->{recaptcha_error} = 'User appears not to have submitted a recaptcha';
+        $c->stash->{recaptcha_error} =
+            'User appears not to have submitted a recaptcha';
         return;
     }
 
-    my $key = $c->config->{recaptcha}->{priv_key} || croak 'must set recaptcha priv_key in config';
-    
+    my $key = $c->config->{recaptcha}->{priv_key} ||
+        croak 'must set recaptcha priv_key in config';
+
     my $result = $cap->check_answer(
         $key,
         $c->req->address,
@@ -38,10 +41,12 @@ sub captcha_check : Private {
         unless ref $result eq 'HASH' && exists $result->{is_valid};
 
 
-    $c->stash->{recaptcha_error} = $result->{error} || 'Unknown error'
-        unless $result->{is_valid};
+    $c->stash->{recaptcha_error} = $result->{error} ||
+        'Unknown error'
+            unless $result->{is_valid};
 
-    return ($result->{is_valid} = $result->{is_valid});
+    $c->stash->{recaptcha_ok} = 1 if $result->{is_valid};
+    return ($result->{is_valid} == $result->{is_valid});
 }
 
 
@@ -60,10 +65,14 @@ a number of C<Private> methods that deal with the recaptcha.
 
 In MyApp.pm (or equivalent in config file):
 
- __PACKAGE__->config->{recaptcha}->{pub_key} = '6LcsbAAAAAAAAPDSlBaVGXjMo1kJHwUiHzO2TDze';
- __PACKAGE__->config->{recaptcha}->{priv_key} = '6LcsbAAAAAAAANQQGqwsnkrTd7QTGRBKQQZwBH-L';
+ __PACKAGE__->config->{recaptcha}->{pub_key} =
+                          '6LcsbAAAAAAAAPDSlBaVGXjMo1kJHwUiHzO2TDze';
+ __PACKAGE__->config->{recaptcha}->{priv_key} =
+                          '6LcsbAAAAAAAANQQGqwsnkrTd7QTGRBKQQZwBH-L';
 
-(the two keys above work for http://localhost).
+(the two keys above work for http://localhost unless someone hammers the
+reCAPTCHA server with failures, in which case the API keys get a temporary
+ban).
 
 =head2 METHOD
 
@@ -76,9 +85,22 @@ Sets $c->stash->{recaptcha} to be the html form for the L<http://recaptcha.net/>
 captcha_check : Private
 
 Validates the reCaptcha using L<Captcha::reCAPTCHA>.  sets
-$c->stash->{recaptcha_ok} which will be 1 on success.  If there's an
-error, $c->stash->{recaptcha_error} is set with the error string
-provided by L<Captcha::reCAPTCHA>.
+$c->stash->{recaptcha_ok} which will be 1 on success. The action also returns
+true if there is success. This means you can do:
+
+ if ( $c->forward(captcha_check) ) {
+   # do something based on the reCAPTCHA passing
+ }
+
+or alternatively:
+
+ if ( $c->stash->{recaptcha_ok} ) {
+   # do something based on the reCAPTCHA passing
+ }
+
+
+If there's an error, $c->stash->{recaptcha_error} is
+set with the error string provided by L<Captcha::reCAPTCHA>.
 
 =head2 EXAMPLES
 
